@@ -4,16 +4,16 @@ from typing import List, Optional, Dict, Type
 
 from pycognaize.common.enums import IqFieldKeyEnum
 from pycognaize.document.page import Page
-from pycognaize.document.tag.tag import Tag
+from pycognaize.document.tag.tag import BoxTag
 
 
 class Field(metaclass=abc.ABCMeta):
     """Base class for all Field types"""
-    tag_class: Type[Tag] = Tag
+    tag_class: Type[BoxTag] = BoxTag
 
     def __init__(self, name: str,
                  value: str = '',
-                 tags: Optional[List[Tag]] = None,
+                 tags: Optional[List[BoxTag]] = None,
                  field_id: Optional[str] = None,
                  group_key: Optional[str] = None,
                  confidence: Optional[float] = -1.0,
